/* This program is free software. It comes without any warranty, to
 * the extent permitted by applicable law. You can redistribute it
 * and/or modify it under the terms of the Do What The F*** You Want
 * To Public License, Version 2, as published by Sam Hocevar. See
 * http://sam.zoy.org/wtfpl/COPYING for more details. */

#include <cstdlib>
#include <iostream>
#include <fstream>
#include <cstring>
#include <FL/Fl.H>
#include <FL/Fl_Window.H>
#include <FL/Fl_Radio_Round_Button.H>
#include <FL/Fl_Choice.H>

#define HEADER "DOUKUTSU20041206"
#define TEXT "Courier New"

struct data{
	char header[32];
	char text[64];
	int move;
	int attack;
	int okay;
	int display;
	char empty[36];
};

Fl_Round_Button *movear;
Fl_Round_Button *movegt;

Fl_Round_Button *buttonxz;
Fl_Round_Button *buttonzx;

Fl_Round_Button *okayjump;
Fl_Round_Button *okayattack;

Fl_Choice *displaychoice;

void quit(Fl_Widget*, void*){
	std::exit(0);
}

void read_Config(){
	std::fstream fd;
	data config;
	fd.open("Config.dat", std::ios::in | std::ios::binary);
	fd.read((char*)&config, 112);
	if (config.move == 0){
		movear->setonly();
	} else {
		movegt->setonly();
	}
	if (config.attack == 0){
		buttonxz->setonly();
	} else { 
		buttonzx->setonly();
	}
	if (config.okay == 0){
		okayjump->setonly();
	}else{
		okayattack->setonly();
	}
	displaychoice->value(config.display);
	fd.close();
}

void write_Config(Fl_Widget*, void*){
	std::fstream fd;
	data config;
	std::memset(config.header, '\0', 32);
	std::memset(config.text, '\0', 64);
	std::strcpy(config.header, HEADER);
	std::strcpy(config.text, TEXT);
	fd.open("Config.dat", std::ios::out | std::ios::binary);
	if (movegt->value() == 1){
		config.move = 1;
	} else {
		config.move = 0;
	}
	if (buttonzx->value() == 1){
		config.attack = 1;
	} else {
		config.attack = 0;
	}
	if (okayattack->value() == 1){
		config.okay = 1;
	} else {
		config.okay = 0;
	}
	config.display = displaychoice->value();
	memset(config.empty, '\0', 36);
	fd.write((char*)&config, 148);
	fd.close();
	exit(0);
}
int main(int argc, char* argv[]){
	Fl_Window *mainw = new Fl_Window(400, 170, "DoConfigure - Doukutsu Monotagari Settings");
	
	Fl_Group *movegroup = new Fl_Group(10, 10, 185, 50);
	movegroup->box(FL_THIN_DOWN_BOX);
	movear = new Fl_Radio_Round_Button(10, 10, 185, 20, "Arrows for Movement");
	movear->setonly();
	movegt = new Fl_Radio_Round_Button(10, 40, 185, 20, "<>? for Movement");
	movegroup->end();
	
	Fl_Group *buttongroup = new Fl_Group(10, 70, 185, 50);
	buttongroup->box(FL_THIN_DOWN_BOX);
	buttonxz = new Fl_Radio_Round_Button(10, 70, 185, 20, "Z=Jump;X=Attack");
	buttonxz->setonly();
	buttonzx = new Fl_Radio_Round_Button(10, 100, 185, 20, "X=Jump;Z=Attack");
	buttongroup->end();
	
	Fl_Group *okaygroup = new Fl_Group(205, 10, 185, 50);
	okaygroup->box(FL_THIN_DOWN_BOX);
	okayjump = new Fl_Radio_Round_Button(205, 10, 185, 20, "Jump=Okay");
	okayjump->setonly();
	okayattack = new Fl_Radio_Round_Button(205, 40, 185, 20, "Attack=Okay");
	okaygroup->end();
	
	displaychoice = new Fl_Choice(205, 80, 185, 20);
	Fl_Menu_Item screens[] = {
		{"Fullscreen 16-bit"},
		{"Windowed 320x240"},
 		{"Windowed 640x480"},
		{"Fullscreen 24-bit"},
		{"Fullscreen 32-bit"},
		{0}};
	displaychoice->menu(screens);
	
	Fl_Button *okaybutton = new Fl_Button(10, 130, 185, 30, "Okay");
	okaybutton->callback(&write_Config);
	Fl_Button *cancelbutton = new Fl_Button(205, 130, 185, 30, "Cancel");
	cancelbutton->callback(&quit);
	mainw->end();
	mainw->show(argc, argv);
	
	read_Config();
	return Fl::run();
}
